==> jc-1.4.0.tar.gz: scm/Symbol.h <==
// class scm.Symbol

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf0c274f950a474b scm_Symbol

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Symbol_H_
#define _JC_scm_Symbol_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;
struct _jc_scm_Symbol$object;

// Typedefs
typedef struct _jc_scm_Symbol$sub_refs	_jc_scm_Symbol$sub_refs;
typedef struct _jc_scm_Symbol$sub_nonrefs	_jc_scm_Symbol$sub_nonrefs;
typedef struct _jc_scm_Symbol$refs	_jc_scm_Symbol$refs;
typedef struct _jc_scm_Symbol$nonrefs	_jc_scm_Symbol$nonrefs;
typedef struct _jc_scm_Symbol$object	_jc_scm_Symbol$object;

typedef struct _jc_scm_Symbol$fields_struct	_jc_scm_Symbol$fields_struct;
typedef const struct _jc_scm_Symbol$vmethods	_jc_scm_Symbol$vmethods;
typedef const struct _jc_scm_Symbol$vtable	_jc_scm_Symbol$vtable;
typedef const struct _jc_scm_Symbol$vtype	_jc_scm_Symbol$vtype;

// Class fields structure
struct _jc_scm_Symbol$fields_struct {
	struct _jc_java_util_Hashtable$object	*internset;
};
extern _jc_scm_Symbol$fields_struct _jc_scm_Symbol$class_fields;

// Constructors
extern void _jc_scm_Symbol$method$_init$c31b894660454d13(_jc_env *, struct _jc_scm_Symbol$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_Symbol$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_Symbol$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_Symbol$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Symbol$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_Symbol$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_Symbol$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_scm_Symbol$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_scm_Symbol$object *_jc_scm_Symbol$method$intern$fa0423caaa1f6861(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_scm_Symbol$vmethods {
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_Symbol$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Symbol$object *);
};

// Vtable
struct _jc_scm_Symbol$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Symbol$vmethods	scm_Symbol;
};

// Vtype
struct _jc_scm_Symbol$vtype {
	_jc_type			type;
	_jc_scm_Symbol$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Symbol$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_scm_Symbol$refs {
    _jc_scm_Symbol$sub_refs	scm_Symbol;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Symbol$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Symbol$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Symbol$sub_nonrefs	scm_Symbol;
};

// Object instance structure
struct _jc_scm_Symbol$object {
	_jc_scm_Symbol$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Symbol$vtype	*vtype;
	_jc_scm_Symbol$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Symbol$vtype _jc_scm_Symbol$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Symbol, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Symbol$class_object;

#endif	/* _JC_scm_Symbol_H_ */

==> jc-1.4.6.tar.gz: scm/Symbol.h <==
// class scm.Symbol

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cf0c274f950a474b scm_Symbol

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Symbol_H_
#define _JC_scm_Symbol_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;
struct _jc_scm_Symbol$object;

// Typedefs
typedef struct _jc_scm_Symbol$sub_refs	_jc_scm_Symbol$sub_refs;
typedef struct _jc_scm_Symbol$sub_nonrefs	_jc_scm_Symbol$sub_nonrefs;
typedef struct _jc_scm_Symbol$refs	_jc_scm_Symbol$refs;
typedef struct _jc_scm_Symbol$nonrefs	_jc_scm_Symbol$nonrefs;
typedef struct _jc_scm_Symbol$object	_jc_scm_Symbol$object;

typedef struct _jc_scm_Symbol$fields_struct	_jc_scm_Symbol$fields_struct;
typedef const struct _jc_scm_Symbol$vmethods	_jc_scm_Symbol$vmethods;
typedef const struct _jc_scm_Symbol$vtable	_jc_scm_Symbol$vtable;
typedef const struct _jc_scm_Symbol$vtype	_jc_scm_Symbol$vtype;

// Class fields structure
struct _jc_scm_Symbol$fields_struct {
	struct _jc_java_util_Hashtable$object	*internset;
};
extern _jc_scm_Symbol$fields_struct _jc_scm_Symbol$class_fields;

// Constructors
extern void _jc_scm_Symbol$method$_init$c31b894660454d13(_jc_env *, struct _jc_scm_Symbol$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_Symbol$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_Symbol$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_Symbol$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Symbol$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_Symbol$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_Symbol$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_scm_Symbol$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_scm_Symbol$object *_jc_scm_Symbol$method$intern$fa0423caaa1f6861(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_scm_Symbol$vmethods {
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_Symbol$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Symbol$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_Symbol$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Symbol$vmethods	scm_Symbol;
};

// Vtype
struct _jc_scm_Symbol$vtype {
	_jc_type			type;
	_jc_scm_Symbol$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Symbol$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_scm_Symbol$refs {
    _jc_scm_Symbol$sub_refs	scm_Symbol;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Symbol$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Symbol$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Symbol$sub_nonrefs	scm_Symbol;
};

// Object instance structure
struct _jc_scm_Symbol$object {
	_jc_scm_Symbol$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Symbol$vtype	*vtype;
	_jc_scm_Symbol$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Symbol$vtype _jc_scm_Symbol$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Symbol, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Symbol$class_object;

#endif	/* _JC_scm_Symbol_H_ */
